#RJAGS Sample Code:
#install.packages("rjags")
library(coda) 
library(rjags)

#Set Working Directory to where you placed the model file


#For this example, I will load the data here
p=3
N=21
Y=c(42, 37, 37, 28, 18, 18, 19, 20, 15, 14, 14, 13, 11, 12, 8, 7, 8, 8, 9, 15, 15)
x=matrix(c(80, 27, 89,80, 27, 88, 75, 25, 90,62, 24, 87,62, 22, 87,62, 23, 87, 62, 24, 93,
62, 24, 93,58, 23, 87,58, 18, 80,58, 18, 89,58, 17, 88,58, 18, 82,58, 19, 93,50, 18, 89,
50, 18, 86,50, 19, 72,50, 19, 79, 50, 20, 80,56, 20, 82, 70, 20, 91),byrow=TRUE,ncol=3)

#Data must be in a list format: 
data=list(p=p,N=N,Y=Y,x=x)

#Initial values
Inits1=list(beta0 = 10, beta=c(0,0, 0), sigma = 0.1)
Inits2=list(beta0 = -10, beta=c(10,10, 10), sigma = 10)

#For Multiple Chains you must have the initial values listed
Inits=list(Inits1,Inits2)

#Now Lets Load the model
#We will have 2 chains, we need to set the data, initial values.
# We will let there be an adaptation period which we take off with burn-in; 
#The adaptation period is an accelerated burn-in period
jags.model=jags.model(file="simplemodel.txt",data=data,inits=Inits,n.chain=2)
#Then it will initialize the model and a bunch of +++++++ will appear

#Then list the parameters you want to estimate
params=c("beta0","beta","sigma") #intercept, slopes, and standard deviation
#Now to sample from the model we do the following: 
samps=coda.samples(jags.model, params, n.iter = 10000)
burn.in=1001
results=summary(window(samps,start=burn.in))
results #provides summary

#Special Things with CODA
gelman.diag(samps) #Provides Gelman Rubin Statistic. We want this value to be less than 1.2 or 1.1 for all parameters
traceplot(samps[,1])
effectiveSize(samps[,2])
autocorr.plot(samps[,1])                        